'use strict';
var express = require('express'),
    router = express.Router(),
    returnCode = require('../../utils/returnCode'),
    _ = require('lodash');
var mongoose = require('mongoose');
var moment = require('moment');

var forumLimitActionService = require('../../service/forumLimitActionService');
var forumLimitActionRefService = require('../../service/forumLimitActionRefService');

module.exports = function(app) {
    app.use('/admin/forum', router);
};

//新增或更新论坛行为限制
router.post('/limitActionRef/createOrUpdate', function(req, res, next) {
    var ent_code = req.session.user.ent_code;
    var mid = req.body.mid;
    var selects = req.body.selects;

    var limit_actions = [];

    var conditions = {
        ent_code: ent_code,
        status: 1
    };
    forumLimitActionService.getAllLimitActionNotPage(conditions, function(err, results) {
        if (err) {
            console.error(err);
            res.json(returnCode.BUSY);
        }
        if(selects && results){
            for (var i = 0; i < selects.length; i+=1) {
                for(var j = 0; j < results.length; j+=1){
                    if (selects[i] === results[j]._id.toString()) {
                        var begin_time = moment(new Date()).format('YYYY-MM-DD');
                        var end_time = moment(new Date()).add(results[j].limit_time, 'days').format('YYYY-MM-DD');
                        var obj = {
                            limit_action: selects[i],
                            limit_action_type: results[j].limit_action_type,
                            begin_time: new Date(begin_time),
                            end_time: new Date(end_time)
                        }
                        limit_actions.push(obj);
                        break;
                    }
                }
            }
        }
        var forumLimitActionRef = {
            ent_code: ent_code,
            mid: mid,
            limit_actions: limit_actions
        }

        forumLimitActionRefService.createOrUpdateLimitActionRef({
            mid: mid,
            ent_code: ent_code,
            status: 1
        }, forumLimitActionRef, function(err, forum) {
            if (err) {
                console.error(err);
                res.json(returnCode.BUSY);
            } else {
                var rs = {
                    data: forum
                }
                res.json(_.assign(rs, returnCode.SUCCESS));
            }
        });
    })
});

//根据mid获取论坛行为限制
router.get('/limitActionRef/:mid/get', function(req, res, next) {
    var mid = req.params.mid;
    if (mid) {
        forumLimitActionRefService.getLimitActionRefByMid(mid, function(err, forumLimitActionRef) {
            if (err) {
                console.error(err);
                res.json(returnCode.BUSY);
            } else {
                var rs = {};
                rs.data = forumLimitActionRef;
                res.json(_.assign(rs, returnCode.SUCCESS));
            }
        });
    } else {
        res.json(returnCode.WRONG_PARAM);
    }
});

//删除论坛行为限制
router.post('/limitActionRef/:rid/delete', function(req, res, next) {
    var rid = req.params.rid;
    if (rid) {
        forumLimitActionRefService.deleteLimitActionRefById(rid, function(err, result) {
            if (err) {
                console.error(err);
                res.json(returnCode.BUSY);
            } else {
                res.json(returnCode.SUCCESS);
            }
        });
    } else {
        res.json(returnCode.WRONG_PARAM);
    }
});

//更新论坛行为限制
router.post('/limitActionRef/:rid/update', function(req, res, next) {
    var rid = req.params.rid;
    if (rid) {
        forumLimitActionRefService.updateLimitActionRefById(rid, req.body, function(err, result) {
            if (err) {
                console.error(err);
                res.json(returnCode.BUSY);
            } else {
                res.json(returnCode.SUCCESS);
            }
        });
    } else {
        res.json(returnCode.WRONG_PARAM);
    }
});

//获取行为限制列表
router.get('/limitActionRef/list', function(req, res, next) {
    var pageNo = req.query.pageNo || 1;
    var pageSize = req.query.pageSize || 10;
    var limitActionName = req.query.limitActionName;

    var conditions = {
        ent_code: req.session.user.ent_code
    };
    if (limitActionName) {
        conditions.title = {
            $regex: limitActionName,
            $options: 'i'
        };
    }
    forumLimitActionRefService.getAllLimitActionRef(conditions, pageNo, pageSize, function(err, results) {
        if (err) {
            console.error(err);
            res.json(returnCode.BUSY);
        } else {
            res.json(_.assign(results, returnCode.SUCCESS));
        }
    });
});
